@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.17'
+__version__ = '2.1.18'
 
 if os.environ.get('SERVER_SOFTWARE') is not None:
     # Google App Engine information
@@ -103,6 +103,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'flairconfig':         'api/flairconfig/',
                  'flaircsv':            'api/flaircsv/',
                  'flairlist':           'r/%s/api/flairlist/',
+                 'flairselector':       'api/flairselector/',
                  'flairtemplate':       'api/flairtemplate/',
                  'friend':              'api/friend/',
                  'friends':             'prefs/friends/',
@@ -627,7 +628,6 @@ class OAuth2Reddit(BaseReddit):
         :param redirect_uri: the redirect_uri of your application
 
         """
-
         self.client_id = client_id
         self.client_secret = client_secret
         self.redirect_uri = redirect_uri
@@ -666,9 +666,7 @@ class UnauthenticatedReddit(BaseReddit):
     @decorators.deprecated(msg="Please use `get_comments(\'all\', ...)` "
                                "instead.")
     def get_all_comments(self, *args, **kwargs):
-        """Return a get_content generator for comments from `all` subreddits.
-
-        """
+        """Return a get_content generator for comments from all subreddits."""
         return self.get_comments('all', *args, **kwargs)
 
     @decorators.restrict_access(scope='read')
@@ -1115,7 +1113,9 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         self.user = None
 
     def delete(self, password, message=""):
-        """Delete the currently authenticated redditor. WARNING!
+        """Delete the currently authenticated redditor.
+
+        WARNING!
 
         This action is IRREVERSIBLE. Use only if you're okay with NEVER
         accessing this reddit account again.
@@ -1125,7 +1125,6 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         :returns: json response from the server.
 
         """
-
         data = {'user': self.user.name,
                 'passwd': password,
                 'delete_message': message,
@@ -1161,6 +1160,23 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
             self.set_access_credentials(**retval)
         return retval
 
+    @decorators.restrict_access(scope='flair')
+    def get_flair_choices(self, subreddit, link=None):
+        """Return available flair choices and current flair.
+
+        :param link: If link is given, return the flair options for this
+            submission. Not normally given directly, but instead set by calling
+            the flair_choices method for Submission objects.
+            use the default for the session's user.
+
+        :returns: A dictionary with 2 keys. 'current' containing current flair
+            settings for the authenticated user and 'choices' containing a list
+            of possible flair choices.
+
+        """
+        data = {'r':  six.text_type(subreddit), 'link': link}
+        return self.request_json(self.config['flairselector'], data=data)
+
     @decorators.restrict_access(scope='identity', oauth_only=True)
     def get_me(self):
         """Return a LoggedInRedditor object."""
@@ -1243,13 +1259,15 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
 
         This can only be used for assigning your own name flair or link flair
         on your own submissions. For assigning other's flairs using moderator
-        access, check :meth:`~praw.__init__.ModFlairMixin.set_flair`
+        access, see :meth:`~praw.__init__.ModFlairMixin.set_flair`.
 
         :param item: A string, Subreddit object (for user flair), or
             Submission object (for link flair). If item is a string it will be
             treated as the name of a Subreddit.
-        :param flair_template_id: 36 characters id found in the HTML of a
-            flair selector.
+        :param flair_template_id: The id for the desired flair template. Use
+            the :meth:`~praw.objects.Subreddit.get_flair_choices` and
+            :meth:`~praw.objects.Submission.get_flair_choices` methods to find
+            the ids for the available user and link flair choices.
         :param flair_text: A String containing the custom flair text.
             Used on subreddits that allow it.
 
@@ -1598,6 +1616,10 @@ class ModFlairMixin(AuthenticatedReddit):
         Item can be a string, Redditor object, or Submission object. If item is
         a string it will be treated as the name of a Redditor.
 
+        This method can only be called by the subreddit moderator. To set flair
+        on yourself or your own links use
+        :meth:`~praw.__init__.AuthenticatedReddit.select_flair`.
+
         :returns: The json response from the server.
 
         """
@@ -2132,6 +2154,5 @@ class Reddit(ModConfigMixin, ModFlairMixin, ModLogMixin, ModOnlyMixin,
 
     """
 
-
 # Prevent recursive import
 from praw import objects
