@@ -138,7 +138,15 @@ class RedditContentObject(object):
         for name, value in six.iteritems(json_dict):
             if self._underscore_names and name in self._underscore_names:
                 name = '_' + name
-            setattr(self, name, value)
+            try:
+                setattr(self, name, value)
+            except AttributeError as exc:
+                # Handle conflicts with PRAW properties.
+                # The attribute from reddit will be suffixed with `_reddit`
+                if exc.args == ('can\'t set attribute',):
+                    setattr(self, 'name' + '_reddit', value)
+                else:
+                    raise
         return bool(json_dict) or fetch
 
     @property
@@ -941,6 +949,18 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         return self.reddit_session.get_content(url, *args, object_filter=1,
                                                **kwargs)
 
+    def get_flair_choices(self, *args, **kwargs):
+        """Return available link flair choices and current flair.
+
+        Convenience function for
+        :meth:`~.AuthenticatedReddit.get_flair_choices` populating both the
+        `subreddit` and `link` parameters.
+
+        :returns: The json response from the server.
+
+        """
+        return self.subreddit.get_flair_choices(self.fullname, *args, **kwargs)
+
     def mark_as_nsfw(self, unmark_nsfw=False):
         """Mark as Not Safe For Work.
 
@@ -1133,6 +1153,7 @@ class Subreddit(Messageable, Refreshable):
                 ('get_comments', UR),
                 ('get_contributors', MOMix),
                 ('get_flair', UR),
+                ('get_flair_choices', AR),
                 ('get_flair_list', MFMix),
                 ('get_moderators', UR),
                 ('get_mod_log', MLMix),
